@@ -6,7 +6,7 @@ package ELF::Extract::Sections::Scanner::Objdump;
 
 # ABSTRACT: An objdump based section scanner.
 
-our $VERSION = '1.001002'; # TRIAL
+our $VERSION = '1.001003'; # TRIAL
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -173,12 +173,33 @@ sub _build__section_header_identifier {
     return qr/${header}\s*${offset}:/;
 }
 
+sub _objdump_win32 {
+    my ($self) = @_;
+    require Capture::Tiny;
+    ## no critic (Subroutines::ProhibitCallsToUnexportedSubs)
+    my ( $stdout, $result ) = Capture::Tiny::capture_stdout(
+        sub {
+            system 'objdump', qw( -D -F ), $self->_file->realpath->absolute;
+        },
+    );
+    if ( $result != 0 ) {
+        $self->log->logconfess(qq{An error occured requesting section data from objdump $^E $@ });
+    }
+    open my $fh, '<', \$stdout or do {
+        $self->log->logconfess(qq{An error occured making a string IO filehandle $! $@ });
+    };
+    return $fh;
+}
+
 sub _objdump {
     my ($self) = @_;
+    if ( 'MSWin32' eq $^O or $ENV{OBJDUMP_SLURP} ) {
+        return $self->_objdump_win32;
+    }
     if ( open my $fh, q{-|}, q{objdump}, qw( -D -F ), $self->_file->realpath->absolute ) {
         return $fh;
     }
-    $self->log->logconfess(qq{An error occured requesting section data from objdump $^ $@ });
+    $self->log->logconfess(qq{An error occured requesting section data from objdump $! $@ });
     return;
 }
 
@@ -196,7 +217,7 @@ ELF::Extract::Sections::Scanner::Objdump - An objdump based section scanner.
 
 =head1 VERSION
 
-version 1.001002
+version 1.001003
 
 =head1 SYNOPSIS
 
